---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2012-04-04;35
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20120406&codiceRedaz=012G0056&dataVigenza=20251104
dataGU: 20120406
codiceRedaz: 012G0056
dataVigenza: 20251104
---

# Conversione in legge, con modificazioni, del decreto-legge 9 febbraio 2012, n. 5, recante disposizioni urgenti in materia di semplificazione e di sviluppo. (12G0056)

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## Art. 1.

1. Il decreto-legge 9 febbraio 2012, n. 5, recante disposizioni urgenti in materia di semplificazione e di sviluppo, e' convertito in legge con le modificazioni riportate in allegato alla presente legge.

2. La presente legge entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale.

